==> tajin-framework-all-2.0-sources.jar: com/ovea/tajin/framework/scheduling/AsyncJobScheduler.java <==
package com.ovea.tajin.framework.scheduling;

import java.util.concurrent.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@javax.inject.Singleton() @com.ovea.tajin.framework.jmx.annotation.JmxBean() public class AsyncJobScheduler
  extends java.lang.Object  implements
    com.ovea.tajin.framework.scheduling.JobScheduler,    com.ovea.tajin.framework.jmx.JmxSelfNaming,    groovy.lang.GroovyObject {
public AsyncJobScheduler
() {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  com.google.common.cache.LoadingCache<java.lang.String, com.ovea.tajin.framework.scheduling.JobExecutor> getExecutors() { return (com.google.common.cache.LoadingCache)null;}
public  void setExecutors(com.google.common.cache.LoadingCache<java.lang.String, com.ovea.tajin.framework.scheduling.JobExecutor> value) { }
public  com.ovea.tajin.framework.scheduling.JobRepository getRepository() { return (com.ovea.tajin.framework.scheduling.JobRepository)null;}
public  void setRepository(com.ovea.tajin.framework.scheduling.JobRepository value) { }
public  com.ovea.tajin.framework.util.PropertySettings getSettings() { return (com.ovea.tajin.framework.util.PropertySettings)null;}
public  void setSettings(com.ovea.tajin.framework.util.PropertySettings value) { }
public  com.ovea.tajin.framework.scheduling.JobScheduler.OnError getOnError() { return (com.ovea.tajin.framework.scheduling.JobScheduler.OnError)null;}
public  void setOnError(com.ovea.tajin.framework.scheduling.JobScheduler.OnError value) { }
public  int getMaxRetry() { return (int)0;}
public  void setMaxRetry(int value) { }
public  int getRetryDelay() { return (int)0;}
public  void setRetryDelay(int value) { }
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  long getScheduledCount() { return (long)0;}
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  long getRunningCount() { return (long)0;}
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  long getTotalExecutionCount() { return (long)0;}
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  long getFailedCount() { return (long)0;}
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  java.util.Collection<java.lang.String> getScheduledJobs() { return (java.util.Collection)null;}
@java.lang.Override() public  javax.management.ObjectName getObjectName()throws javax.management.MalformedObjectNameException { return (javax.management.ObjectName)null;}
@javax.annotation.PostConstruct() public  void init() { }
@javax.annotation.PreDestroy() public  void close() { }
@java.lang.Override() public  com.ovea.tajin.framework.scheduling.Job schedule(java.lang.String jobName, java.util.Map<java.lang.String, ?> data) { return (com.ovea.tajin.framework.scheduling.Job)null;}
@java.lang.Override() public  void cancel(java.util.Collection<java.lang.String> jobIds) { }
@java.lang.Override() public  com.ovea.tajin.framework.scheduling.Job schedule(java.lang.String jobName, java.util.Date time, java.util.Map<java.lang.String, ?> data) { return (com.ovea.tajin.framework.scheduling.Job)null;}
private class JobRunner
  extends java.lang.Object  implements
    java.lang.Runnable,    groovy.lang.GroovyObject {
public JobRunner
(com.ovea.tajin.framework.scheduling.Job job) {
super ();
}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public final  com.ovea.tajin.framework.scheduling.Job getJob() { return (com.ovea.tajin.framework.scheduling.Job)null;}
@java.lang.Override() public  void run() { }
}
}

==> tajin-framework-all-2.4-sources.jar: com/ovea/tajin/framework/scheduling/AsyncJobScheduler.java <==
package com.ovea.tajin.framework.scheduling;

import java.util.concurrent.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@javax.inject.Singleton() @com.ovea.tajin.framework.jmx.annotation.JmxBean() public class AsyncJobScheduler
  extends java.lang.Object  implements
    com.ovea.tajin.framework.scheduling.JobScheduler,    com.ovea.tajin.framework.jmx.JmxSelfNaming,    groovy.lang.GroovyObject {
public AsyncJobScheduler
() {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  com.google.common.cache.LoadingCache<java.lang.String, com.ovea.tajin.framework.scheduling.JobExecutor> getExecutors() { return (com.google.common.cache.LoadingCache)null;}
public  void setExecutors(com.google.common.cache.LoadingCache<java.lang.String, com.ovea.tajin.framework.scheduling.JobExecutor> value) { }
public  com.ovea.tajin.framework.scheduling.JobRepository getRepository() { return (com.ovea.tajin.framework.scheduling.JobRepository)null;}
public  void setRepository(com.ovea.tajin.framework.scheduling.JobRepository value) { }
public  com.ovea.tajin.framework.util.PropertySettings getSettings() { return (com.ovea.tajin.framework.util.PropertySettings)null;}
public  void setSettings(com.ovea.tajin.framework.util.PropertySettings value) { }
public  com.ovea.tajin.framework.scheduling.JobScheduler.OnError getOnError() { return (com.ovea.tajin.framework.scheduling.JobScheduler.OnError)null;}
public  void setOnError(com.ovea.tajin.framework.scheduling.JobScheduler.OnError value) { }
public  int getMaxRetry() { return (int)0;}
public  void setMaxRetry(int value) { }
public  int getRetryDelay() { return (int)0;}
public  void setRetryDelay(int value) { }
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  long getScheduledCount() { return (long)0;}
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  long getRunningCount() { return (long)0;}
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  long getTotalExecutionCount() { return (long)0;}
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  long getFailedCount() { return (long)0;}
@com.ovea.tajin.framework.jmx.annotation.JmxProperty() public  java.util.Collection<java.lang.String> getScheduledJobs() { return (java.util.Collection)null;}
@java.lang.Override() public  javax.management.ObjectName getObjectName()throws javax.management.MalformedObjectNameException { return (javax.management.ObjectName)null;}
@javax.annotation.PostConstruct() public  void init() { }
@javax.annotation.PreDestroy() public  void close() { }
@java.lang.Override() public  void cancel(java.util.Collection<java.lang.String> jobIds) { }
@java.lang.Override() public  com.ovea.tajin.framework.scheduling.Job submit(java.lang.String jobName, java.util.Map<java.lang.String, ?> data) { return (com.ovea.tajin.framework.scheduling.Job)null;}
@java.lang.Override() public  com.ovea.tajin.framework.scheduling.Job submit(java.lang.String jobName, java.util.Date time, java.util.Map<java.lang.String, ?> data) { return (com.ovea.tajin.framework.scheduling.Job)null;}
@java.lang.Override() public  com.ovea.tajin.framework.scheduling.Job schedule(java.lang.String jobName, java.util.Map<java.lang.String, ?> data) { return (com.ovea.tajin.framework.scheduling.Job)null;}
@java.lang.Override() public  com.ovea.tajin.framework.scheduling.Job schedule(java.lang.String jobName, java.util.Date time, java.util.Map<java.lang.String, ?> data) { return (com.ovea.tajin.framework.scheduling.Job)null;}
private class JobRunner
  extends java.lang.Object  implements
    java.lang.Runnable,    groovy.lang.GroovyObject {
public JobRunner
(com.ovea.tajin.framework.scheduling.Job job) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public final  com.ovea.tajin.framework.scheduling.Job getJob() { return (com.ovea.tajin.framework.scheduling.Job)null;}
@java.lang.Override() public final  void run() { }
public  void onComplete() { }
public  void onFailure() { }
public  boolean isRetryable() { return false;}
}
private class PersistentJobRunner
  extends com.ovea.tajin.framework.scheduling.AsyncJobScheduler.JobRunner {
public PersistentJobRunner
(com.ovea.tajin.framework.scheduling.Job job) {
super ((com.ovea.tajin.framework.scheduling.Job)null);
}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
@java.lang.Override() public  void onComplete() { }
@java.lang.Override() public  void onFailure() { }
@java.lang.Override() public  boolean isRetryable() { return false;}
}
}
